@@ -1,3 +1,4 @@
+# coding:utf-8
 import time
 import zxing
 from socket import*
@@ -52,64 +53,34 @@ def getweather(province,city):
         return data
     except:
         return -1
-
-def get_news():
-    now = time.strftime("%Y-%m-%d", time.localtime())
-    print(now,"最新新闻资讯,转载于人民日报。\n")
-    now = time.strftime("%Y%m%d", time.localtime())
-    now1 = time.strftime("%Y-%m/%d", time.localtime())
-    print("今日新闻资讯:")
-    for i in range(1,10):
-        try:
-            url="http://paper.people.com.cn/rmrb/html/"+now1+"/nw.D110000renmrb_"+now+"_3-0"+str(i)+".htm"
-            html=urlopen(url).read().decode("utf-8")
-            html=html.replace("<br>","")
-            html=html.replace("&nbsp;","")
-            html=html.replace("<P>","")
-            html=html.replace("</P>","")
-            a1=html.index("<title>")+len("<title>")
-            b1=html.index("</title>")
-            a=html.index("<!--enpcontent-->")+19
-            b=html.index("<!--/enpcontent-->")
-            print(i,".",end="")
-            while a1<b1:
-                print(html[a1],end="")
-                a1+=1
-            print("\n")
-        except:
-            last=i-1
-            break
+import json
+import requests
+from bs4 import BeautifulSoup
+def get_newslist():
+    import requests
     try:
-        number=int(input("您需要的看点:"))
+        newslist=[]
+        url="https://i.news.qq.com/trpc.qqnews_web.pc_base_srv.base_http_proxy/NinjaPageContentSync?pull_urls=news_top_2018"
+        data=requests.get(url)
+        if data.status_code==200:
+            data=json.loads(data.text)
+            for i in range(len(data['data'])):
+                dict={'title':data['data'][i]['title'],'url':data['data'][i]['url']}
+                newslist.append(dict)
+            return newslist
     except:
         return -1
-    if number>last or number<1:
+def get_newstext(url):
+    try:
+        html = urllib.request.urlopen(url).read().decode("gbk")
+        par = '(<meta name="description" content=")(.*?)(">)'
+        try:
+            data = re.search(par, html).group(2)
+            return data
+        except:
+            return -1
+    except:
         return -1
-    url="http://paper.people.com.cn/rmrb/html/"+now1+"/nw.D110000renmrb_"+now+"_3-0"+str(number)+".htm"
-    html=urlopen(url).read().decode("utf-8")
-    html=html.replace("<P>","")
-    html=html.replace("</P>","")
-    html=html.replace("<br>","")
-    html=html.replace("&nbsp;","")
-    a1=html.index("<title>")+len("<title>")
-    b1=html.index("</title>")
-    a=html.index("<!--enpcontent-->")+19
-    b=html.index("<!--/enpcontent-->")
-    print("标题:")
-    while a1<b1:
-        print(html[a1],end="")
-        a1+=1
-    print("\033[33m")
-    while a1<b1:
-        print(html[a1],end="")
-        a1+=1
-    print("\033[0m")
-    print("\n内容:")
-    print("\033[44m",end="  ")
-    while a<b:
-        print(html[a],end="")
-        a+=1
-    print("\033[0m")
 
 def printf(text,ts=0.1):
     text=str(text)
@@ -146,4 +117,6 @@ def find_lib(libname):
     except:
         return -1
 def download_lib(lib):
-    os.system(sys.executable + " -m pip install " + lib + " -i https://pypi.douban.com/simple")
\ No newline at end of file
+    os.system(sys.executable + " -m pip install " + lib + " -i https://pypi.douban.com/simple")
+a=get_newsnum()
+print(get_newstext(a[0]['url']),"\n")
\ No newline at end of file
